summaryrefslogtreecommitdiffstats
path: root/ksvg/impl/libs
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:00 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:00 -0600
commitec1fddcd0d6663ad273af85357f04abbc5689468 (patch)
tree6cb946ab8b4771868c6eee8d1aa5213d6ec246e2 /ksvg/impl/libs
parentc2637a0da6d9a1c8626ca39f8451ab3b7cda487a (diff)
downloadtdegraphics-ec1fddcd0d6663ad273af85357f04abbc5689468.tar.gz
tdegraphics-ec1fddcd0d6663ad273af85357f04abbc5689468.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit c2637a0da6d9a1c8626ca39f8451ab3b7cda487a.
Diffstat (limited to 'ksvg/impl/libs')
-rw-r--r--ksvg/impl/libs/art_support/art_rgba_svp.c4
-rw-r--r--ksvg/impl/libs/libtext2path/src/Converter.cpp28
-rw-r--r--ksvg/impl/libs/libtext2path/src/Font.cpp6
-rw-r--r--ksvg/impl/libs/libtext2path/src/Glyph.cpp6
-rw-r--r--ksvg/impl/libs/libtext2path/src/Glyph.h4
-rw-r--r--ksvg/impl/libs/xrgbrender/gdk-pixbuf-xlib-drawable.c10
6 files changed, 29 insertions, 29 deletions
diff --git a/ksvg/impl/libs/art_support/art_rgba_svp.c b/ksvg/impl/libs/art_support/art_rgba_svp.c
index 47c7d924..04ea81fc 100644
--- a/ksvg/impl/libs/art_support/art_rgba_svp.c
+++ b/ksvg/impl/libs/art_support/art_rgba_svp.c
@@ -415,7 +415,7 @@ art_ksvg_rgba_svp_alpha_mask_callback(void *callback_data, int y,
* @rowstride: Rowstride of @buf buffer.
* @alphagamma: #ArtAlphaGamma for gamma-correcting the compositing.
*
- * Renders the shape specified with @svp over the @buf RGB buffer.
+ * Renders the tqshape specified with @svp over the @buf RGB buffer.
* @x1 - @x0 specifies the width, and @y1 - @y0 specifies the height,
* of the rectangle rendered. The new pixels are stored starting at
* the first byte of @buf. Thus, the @x0 and @y0 parameters specify
@@ -600,7 +600,7 @@ art_ksvg_rgb_svp_alpha_mask_callback(void *callback_data, int y,
* @rowstride: Rowstride of @buf buffer.
* @alphagamma: #ArtAlphaGamma for gamma-correcting the compositing.
*
- * Renders the shape specified with @svp over the @buf RGB buffer.
+ * Renders the tqshape specified with @svp over the @buf RGB buffer.
* @x1 - @x0 specifies the width, and @y1 - @y0 specifies the height,
* of the rectangle rendered. The new pixels are stored starting at
* the first byte of @buf. Thus, the @x0 and @y0 parameters specify
diff --git a/ksvg/impl/libs/libtext2path/src/Glyph.cpp b/ksvg/impl/libs/libtext2path/src/Glyph.cpp
index d2e16189..08ad55a8 100644
--- a/ksvg/impl/libs/libtext2path/src/Glyph.cpp
+++ b/ksvg/impl/libs/libtext2path/src/Glyph.cpp
@@ -309,14 +309,14 @@ void GlyphRenderParams::setFont(Font *font)
m_font = font;
}
-const GlyphLayoutParams *GlyphRenderParams::layout() const
+const GlyphLayoutParams *GlyphRenderParams::tqlayout() const
{
return m_layout;
}
-void GlyphRenderParams::setLayout(const GlyphLayoutParams *layout)
+void GlyphRenderParams::setLayout(const GlyphLayoutParams *tqlayout)
{
- m_layout = layout;
+ m_layout = tqlayout;
}
unsigned int GlyphRenderParams::glyphIndex() const
diff --git a/ksvg/impl/libs/libtext2path/src/Glyph.h b/ksvg/impl/libs/libtext2path/src/Glyph.h
index b3bd3fb5..8dcbe599 100644
--- a/ksvg/impl/libs/libtext2path/src/Glyph.h
+++ b/ksvg/impl/libs/libtext2path/src/Glyph.h
@@ -171,8 +171,8 @@ namespace T2P
Font *font() const;
void setFont(Font *font);
- const GlyphLayoutParams *layout() const;
- void setLayout(const GlyphLayoutParams *layout);
+ const GlyphLayoutParams *tqlayout() const;
+ void setLayout(const GlyphLayoutParams *tqlayout);
unsigned int glyphIndex() const;
void setGlyphIndex(unsigned int glyphIndex);
diff --git a/ksvg/impl/libs/xrgbrender/gdk-pixbuf-xlib-drawable.c b/ksvg/impl/libs/xrgbrender/gdk-pixbuf-xlib-drawable.c
index 01f60976..70c00262 100644
--- a/ksvg/impl/libs/xrgbrender/gdk-pixbuf-xlib-drawable.c
+++ b/ksvg/impl/libs/xrgbrender/gdk-pixbuf-xlib-drawable.c
@@ -1103,19 +1103,19 @@ xlib_window_is_viewable (Window w)
XWindowAttributes wa;
while (w != 0) {
- Window parent, root, *children;
- int nchildren;
+ Window parent, root, *tqchildren;
+ int ntqchildren;
XGetWindowAttributes (gdk_pixbuf_dpy, w, &wa);
if (wa.map_state != IsViewable)
return 0;
if (!XQueryTree (gdk_pixbuf_dpy, w, &root,
- &parent, &children, &nchildren))
+ &parent, &tqchildren, &ntqchildren))
return 0;
- if (nchildren > 0)
- XFree (children);
+ if (ntqchildren > 0)
+ XFree (tqchildren);
if (parent == root)
return 1;
diff --git a/ksvg/impl/libs/libtext2path/src/Converter.cpp b/ksvg/impl/libs/libtext2path/src/Converter.cpp
index 59ab8e5c..11de3177 100644
--- a/ksvg/impl/libs/libtext2path/src/Converter.cpp
+++ b/ksvg/impl/libs/libtext2path/src/Converter.cpp
@@ -125,7 +125,7 @@ GlyphAffinePair *Converter::requestGlyph(GlyphRenderParams *params, Rectangle &b
SharedGlyph cached = m_glyphCache.find(cacheGlyphKey(params));
// If not available in cache, render new one and cache it :)
// If we're mixing ie. japanese and latin characters (TTB layout),
// then we also have to re-calculate the glyph again with the appropriate rotation matrix (Niko)
if(!cached || !onlyLatin)
cached = calcGlyph(params, affine, onlyLatin);
@@ -164,11 +164,11 @@ void Converter::selectGlyph(GlyphRenderParams *params)
// 3. Don't pass FT_LOAD_VERTICAL_LAYOUT on TTB layouts when rendering
// a latin glyph because it needs to be rotated...
- if(params->layout()->tb())
+ if(params->tqlayout()->tb())
{
Script script;
SCRIPT_FOR_CHAR(script, params->character())
- if(script != Latin || params->layout()->glyphOrientationVertical() == 0)
+ if(script != Latin || params->tqlayout()->glyphOrientationVertical() == 0)
flags |= FT_LOAD_VERTICAL_LAYOUT;
}
@@ -193,7 +193,7 @@ SharedGlyph Converter::calcGlyph(const GlyphRenderParams *params, Affine &affine
affine.dx() += kx + affine.m21() * ky;
// Only apply y kerning in TB mode
- if(params->layout()->tb())
+ if(params->tqlayout()->tb())
affine.dy() += kx + affine.m22() * ky;
}
@@ -206,7 +206,7 @@ SharedGlyph Converter::calcGlyph(const GlyphRenderParams *params, Affine &affine
traceAffine.scale(1000.0 / params->font()->fontFace()->units_per_EM);
// 3b. Enable character rotation, if needed
- if(params->layout()->tb())
+ if(params->tqlayout()->tb())
{
Script script;
SCRIPT_FOR_CHAR(script, params->character())
@@ -214,7 +214,7 @@ SharedGlyph Converter::calcGlyph(const GlyphRenderParams *params, Affine &affine
{
FT_Matrix matrix;
- double angle = deg2rad * params->layout()->glyphOrientationVertical();
+ double angle = deg2rad * params->tqlayout()->glyphOrientationVertical();
matrix.xx = (FT_Fixed)( cos(angle) * 0x10000L);
matrix.xy = (FT_Fixed)(-sin(angle) * 0x10000L);
matrix.yx = (FT_Fixed)( sin(angle) * 0x10000L);
@@ -257,21 +257,21 @@ GlyphSet *Converter::calcString(Font *font, const unsigned short *text, unsigned
if(params->useBidi())
{
FriBidiCharType baseDir = FRIBIDI_TYPE_N;
- FriBidiChar *unicodeIn = new FriBidiChar[length + 1];
- FriBidiChar *unicodeOut = new FriBidiChar[length + 1];
+ FriBidiChar *tqunicodeIn = new FriBidiChar[length + 1];
+ FriBidiChar *tqunicodeOut = new FriBidiChar[length + 1];
bidi = new unsigned short[length + 1];
for(unsigned int i = 0; i < length; i++)
- unicodeIn[i] = text[i];
+ tqunicodeIn[i] = text[i];
- fribidi_log2vis(unicodeIn, length, &baseDir, unicodeOut, 0, 0, 0);
+ fribidi_log2vis(tqunicodeIn, length, &baseDir, tqunicodeOut, 0, 0, 0);
for(unsigned int i = 0; i < length; i++)
- bidi[i] = unicodeOut[i];
+ bidi[i] = tqunicodeOut[i];
bidi[length] = 0;
- delete []unicodeIn;
- delete []unicodeOut;
+ delete []tqunicodeIn;
+ delete []tqunicodeOut;
}
else
bidi = const_cast<unsigned short *>(text);
@@ -302,7 +302,7 @@ GlyphSet *Converter::calcString(Font *font, const unsigned short *text, unsigned
int pixelUnderlineThickness = T2PMAX(1, (int) ((font->fontFace()->underline_thickness * fontSize / font->fontFace()->units_per_EM) * affine.m22()));
// 3. Prepare needed variables for the rendering loop
// - rendering params (layout, font...)
// - bounding box (per glyph, overall)
// - glyph matrix (overall)
// - resulting glyph sets
@@ -125,7 +125,7 @@ GlyphAffinePair *Converter::requestGlyph(GlyphRenderParams *params, Rectangle &b
SharedGlyph cached = m_glyphCache.find(cacheGlyphKey(params));
// If not available in cache, render new one and cache it :)
- // If we're mixing ie. japanese and latin characters (TTB layout),
+ // If we're mixing ie. japanese and latin characters (TTB tqlayout),
// then we also have to re-calculate the glyph again with the appropriate rotation matrix (Niko)
if(!cached || !onlyLatin)
@@ -302,7 +302,7 @@ GlyphSet *Converter::calcString(Font *font, const unsigned short *text, unsigned
int pixelUnderlineThickness = T2PMAX(1, (int) ((font->fontFace()->underline_thickness * fontSize / font->fontFace()->units_per_EM) * affine.m22()));
// 3. Prepare needed variables for the rendering loop
- // - rendering params (layout, font...)
+ // - rendering params (tqlayout, font...)
// - bounding box (per glyph, overall)
// - glyph matrix (overall)
diff --git a/ksvg/impl/libs/libtext2path/src/Font.cpp b/ksvg/impl/libs/libtext2path/src/Font.cpp
index 1d6f7005..2ced971d 100644
--- a/ksvg/impl/libs/libtext2path/src/Font.cpp
+++ b/ksvg/impl/libs/libtext2path/src/Font.cpp
@@ -141,7 +141,7 @@ std::string Font::buildRequest(const FontVisualParams *fontParams, int &id)
FcPatternAddString(pattern, FC_FAMILY, reinterpret_cast<const FcChar8 *>(string.c_str()));
}
- // Always load vertical layout
+ // Always load vertical tqlayout
FcPatternAddBool(pattern, FC_VERTICAL_LAYOUT, true);
// Disable hinting
@@ -208,7 +208,7 @@ bool Font::load(const FontVisualParams *fontParams)
return false;
}
// Choose unicode charmap
for(int charmap = 0; charmap < m_fontFace->num_charmaps; charmap++)
{
if(m_fontFace->charmaps[charmap]->encoding == ft_encoding_unicode)
@@ -217,7 +217,7 @@ bool Font::load(const FontVisualParams *fontParams)
if(error)
{
- std::cout << "Font::load(), unable to select unicode charmap. Aborting!" << std::endl;
+ std::cout << "Font::load(), unable to select tqunicode charmap. Aborting!" << std::endl;
FT_Done_Face(m_fontFace);
m_fontFace = 0;
@@ -208,7 +208,7 @@ bool Font::load(const FontVisualParams *fontParams)
return false;
}
- // Choose unicode charmap
+ // Choose tqunicode charmap
for(int charmap = 0; charmap < m_fontFace->num_charmaps; charmap++)
{